@@ -9,9 +9,12 @@
 #include <QDBusPendingReply>
 #include <QDBusReply>
 #include <QDBusUnixFileDescriptor>
+#include <QLoggingCategory>
 
 #include "common/commondefine.h"
 
+Q_DECLARE_LOGGING_CATEGORY(logCommon)
+
 UpdateDBusProxy::UpdateDBusProxy(QObject *parent)
     : QObject(parent)
     , m_hostname1Inter(new DDBusInterface(
@@ -39,6 +42,7 @@ UpdateDBusProxy::UpdateDBusProxy(QObject *parent)
     , m_interWatcher(new QDBusServiceWatcher(UpdaterService, QDBusConnection::systemBus()))
 
 {
+    qCDebug(logCommon) << "Initialize UpdateDBusProxy with multiple services";
     qRegisterMetaType<LastoreUpdatePackagesInfo>("LastoreUpdatePackagesInfo");
     qDBusRegisterMetaType<LastoreUpdatePackagesInfo>();
 
@@ -48,12 +52,14 @@ UpdateDBusProxy::UpdateDBusProxy(QObject *parent)
     m_interWatcher->setWatchedServices({UpdaterService, ManagerInterface, HostnameService});
 
     connect(m_interWatcher, &QDBusServiceWatcher::serviceRegistered, this, [this](const QString &serviceName) {
+        qCDebug(logCommon) << "DBus service registered:" << serviceName;
         if (serviceName == ManagerService) {
             emit managerInterServiceValidChanged(true);
         }
     });
 
     connect(m_interWatcher, &QDBusServiceWatcher::serviceUnregistered, this, [this](const QString &serviceName) {
+        qCDebug(logCommon) << "DBus service unregistered:" << serviceName;
         if (serviceName == ManagerService) {
             emit managerInterServiceValidChanged(false);
         }
@@ -62,6 +68,7 @@ UpdateDBusProxy::UpdateDBusProxy(QObject *parent)
 
 UpdateDBusProxy::~UpdateDBusProxy()
 {
+    qCDebug(logCommon) << "Destroying UpdateDBusProxy, cleaning up interfaces";
     m_hostname1Inter->deleteLater();
     m_updateInter->deleteLater();
     m_managerInter->deleteLater();
@@ -81,6 +88,7 @@ bool UpdateDBusProxy::updateNotify()
 
 void UpdateDBusProxy::SetUpdateNotify(bool in0)
 {
+    qCDebug(logCommon) << "Setting update notify:" << in0;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     m_updateInter->asyncCallWithArgumentList(QStringLiteral("SetUpdateNotify"), argumentList);
@@ -88,6 +96,7 @@ void UpdateDBusProxy::SetUpdateNotify(bool in0)
 
 LastoreUpdatePackagesInfo UpdateDBusProxy::classifiedUpdatablePackages()
 {
+    qCDebug(logCommon) << "Getting classified updatable packages";
     QDBusInterface updateInter(m_updateInter->service(),
                                m_updateInter->path(),
                                PropertiesInterface,
@@ -99,20 +108,26 @@ LastoreUpdatePackagesInfo UpdateDBusProxy::classifiedUpdatablePackages()
     const QDBusArgument arg = v.value<QDBusVariant>().variant().value<QDBusArgument>();
     LastoreUpdatePackagesInfo packagesInfo;
     arg >> packagesInfo;
+    qCDebug(logCommon) << "Got packages info with" << packagesInfo.size() << "categories";
     return packagesInfo;
 }
 
-double UpdateDBusProxy::GetCheckIntervalAndTime(QString &out1)
+QString UpdateDBusProxy::GetCheckIntervalAndTime()
 {
+    qCDebug(logCommon) << "Getting check interval and time";
     QList<QVariant> argumentList;
     QDBusMessage reply =
             m_updateInter->callWithArgumentList(QDBus::Block,
                                                 QStringLiteral("GetCheckIntervalAndTime"),
                                                 argumentList);
     if (reply.type() == QDBusMessage::ReplyMessage && reply.arguments().count() == 2) {
-        out1 = qdbus_cast<QString>(reply.arguments().at(1));
+        QString checkTime = qdbus_cast<QString>(reply.arguments().at(1));
+        qCDebug(logCommon) << "Check time:" << checkTime;
+        return checkTime;
+    } else if (reply.type() == QDBusMessage::ErrorMessage) {
+        qCWarning(logCommon) << "GetCheckIntervalAndTime failed: " << reply.errorMessage();
     }
-    return qdbus_cast<double>(reply.arguments().at(0));
+    return {};
 }
 
 bool UpdateDBusProxy::autoDownloadUpdates()
@@ -137,6 +152,7 @@ bool UpdateDBusProxy::autoCheckUpdates()
 
 void UpdateDBusProxy::SetAutoCheckUpdates(bool in0)
 {
+    qCDebug(logCommon) << "Setting auto check updates:" << in0;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     m_updateInter->asyncCallWithArgumentList(QStringLiteral("SetAutoCheckUpdates"), argumentList);
@@ -144,6 +160,7 @@ void UpdateDBusProxy::SetAutoCheckUpdates(bool in0)
 
 void UpdateDBusProxy::SetAutoDownloadUpdates(bool in0)
 {
+    qCDebug(logCommon) << "Setting auto download updates:" << in0;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     m_updateInter->asyncCallWithArgumentList(QStringLiteral("SetAutoDownloadUpdates"),
@@ -152,11 +169,13 @@ void UpdateDBusProxy::SetAutoDownloadUpdates(bool in0)
 
 void UpdateDBusProxy::setAutoInstallUpdates(bool value)
 {
+    qCDebug(logCommon) << "Setting auto install updates property:" << value;
     m_updateInter->setProperty("AutoInstallUpdates", QVariant::fromValue(value));
 }
 
 void UpdateDBusProxy::SetMirrorSource(const QString &in0)
 {
+    qCDebug(logCommon) << "Setting mirror source:" << in0;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     m_updateInter->asyncCallWithArgumentList(QStringLiteral("SetMirrorSource"), argumentList);
@@ -174,6 +193,7 @@ quint64 UpdateDBusProxy::updateMode()
 
 void UpdateDBusProxy::setUpdateMode(quint64 value)
 {
+    qCDebug(logCommon) << "Setting update mode:" << value;
     m_managerInter->setProperty("UpdateMode", QVariant::fromValue(value));
 }
 
@@ -204,6 +224,7 @@ quint64 UpdateDBusProxy::checkUpdateMode()
 
 void UpdateDBusProxy::setCheckUpdateMode(quint64 value)
 {
+    qCDebug(logCommon) << "Setting check update mode:" << value;
     m_managerInter->setProperty("CheckUpdateMode", QVariant::fromValue(value));
 }
 
@@ -224,11 +245,13 @@ bool UpdateDBusProxy::p2pUpdateEnable()
 
 QDBusPendingCall UpdateDBusProxy::CanRollback()
 {
+    qCDebug(logCommon) << "Calling CanRollback async";
     return m_managerInter->asyncCall(QStringLiteral("CanRollback"));
 }
 
 QDBusPendingCall UpdateDBusProxy::ConfirmRollback(bool confirm)
 {
+    qCDebug(logCommon) << "Calling ConfirmRollback with confirm:" << confirm;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(confirm);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("ConfirmRollback"), argumentList);
@@ -236,6 +259,7 @@ QDBusPendingCall UpdateDBusProxy::ConfirmRollback(bool confirm)
 
 QDBusPendingCall UpdateDBusProxy::Poweroff(bool reboot)
 {
+    qCDebug(logCommon) << "Calling Poweroff with reboot:" << reboot;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(reboot);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("PowerOff"), argumentList);
@@ -243,12 +267,14 @@ QDBusPendingCall UpdateDBusProxy::Poweroff(bool reboot)
 
 QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::UpdateSource()
 {
+    qCDebug(logCommon) << "Calling UpdateSource async";
     QList<QVariant> argumentList;
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("UpdateSource"), argumentList);
 }
 
 void UpdateDBusProxy::CleanJob(const QString &in0)
 {
+    qCDebug(logCommon) << "Calling CleanJob for job:" << in0;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     m_managerInter->asyncCallWithArgumentList(QStringLiteral("CleanJob"), argumentList);
@@ -256,6 +282,7 @@ void UpdateDBusProxy::CleanJob(const QString &in0)
 
 void UpdateDBusProxy::SetAutoClean(bool in0)
 {
+    qCDebug(logCommon) << "Setting auto clean:" << in0;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     m_managerInter->asyncCallWithArgumentList(QStringLiteral("SetAutoClean"), argumentList);
@@ -263,6 +290,7 @@ void UpdateDBusProxy::SetAutoClean(bool in0)
 
 void UpdateDBusProxy::StartJob(const QString &in0)
 {
+    qCDebug(logCommon) << "Starting job:" << in0;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     m_managerInter->asyncCallWithArgumentList(QStringLiteral("StartJob"), argumentList);
@@ -270,6 +298,7 @@ void UpdateDBusProxy::StartJob(const QString &in0)
 
 void UpdateDBusProxy::PauseJob(const QString &in0)
 {
+    qCDebug(logCommon) << "Pausing job:" << in0;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     m_managerInter->asyncCallWithArgumentList(QStringLiteral("PauseJob"), argumentList);
@@ -278,6 +307,7 @@ void UpdateDBusProxy::PauseJob(const QString &in0)
 QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::InstallPackage(const QString &jobname,
                                                                    const QString &packages)
 {
+    qCDebug(logCommon) << "Installing package with job:" << jobname << "packages:" << packages;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(jobname) << QVariant::fromValue(packages);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("InstallPackage"),
@@ -287,6 +317,7 @@ QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::InstallPackage(const QString
 QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::RemovePackage(const QString &jobname,
                                                                   const QString &packages)
 {
+    qCDebug(logCommon) << "Removing package with job:" << jobname << "packages:" << packages;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(jobname) << QVariant::fromValue(packages);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("RemovePackage"), argumentList);
@@ -294,6 +325,7 @@ QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::RemovePackage(const QString
 
 QDBusPendingReply<QList<QDBusObjectPath>> UpdateDBusProxy::ClassifiedUpgrade(qulonglong in0)
 {
+    qCDebug(logCommon) << "Starting classified upgrade with types:" << in0;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("ClassifiedUpgrade"),
@@ -302,6 +334,7 @@ QDBusPendingReply<QList<QDBusObjectPath>> UpdateDBusProxy::ClassifiedUpgrade(qul
 
 QDBusPendingReply<qlonglong> UpdateDBusProxy::PackagesDownloadSize(const QStringList &in0)
 {
+    qCDebug(logCommon) << "Getting download size for" << in0.size() << "packages";
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(in0);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("PackagesDownloadSize"),
@@ -310,6 +343,7 @@ QDBusPendingReply<qlonglong> UpdateDBusProxy::PackagesDownloadSize(const QString
 
 QDBusPendingReply<bool> UpdateDBusProxy::PackageExists(const QString &pkgid)
 {
+    qCDebug(logCommon) << "Checking if package exists:" << pkgid;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(pkgid);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("PackageExists"), argumentList);
@@ -317,11 +351,13 @@ QDBusPendingReply<bool> UpdateDBusProxy::PackageExists(const QString &pkgid)
 
 QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::DistUpgrade()
 {
+    qCDebug(logCommon) << "Starting full distribution upgrade";
     return m_managerInter->asyncCall(QStringLiteral("DistUpgrade"));
 }
 
 QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::DistUpgradePartly(int updateTypes, bool doBackup)
 {
+    qCDebug(logCommon) << "Starting partial distribution upgrade, types:" << updateTypes << "backup:" << doBackup;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(updateTypes) << QVariant::fromValue(doBackup);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("DistUpgradePartly"),argumentList);
@@ -329,6 +365,7 @@ QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::DistUpgradePartly(int update
 
 QDBusPendingReply<void> UpdateDBusProxy::SetDownloadSpeedLimit(const QString& config)
 {
+    qCDebug(logCommon) << "Setting download speed limit config:" << config;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(config);
     return m_updateInter->asyncCallWithArgumentList(QStringLiteral("SetDownloadSpeedLimit"), argumentList);
@@ -336,6 +373,7 @@ QDBusPendingReply<void> UpdateDBusProxy::SetDownloadSpeedLimit(const QString& co
 
 QDBusPendingReply<qlonglong> UpdateDBusProxy::QueryAllSizeWithSource(int updatetype)
 {
+    qCDebug(logCommon) << "Querying size for update type:" << updatetype;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(updatetype);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("QueryAllSizeWithSource"), argumentList);
@@ -343,6 +381,7 @@ QDBusPendingReply<qlonglong> UpdateDBusProxy::QueryAllSizeWithSource(int updatet
 
 QDBusPendingReply<QString> UpdateDBusProxy::GetUpdateLogs(int updateType)
 {
+    qCDebug(logCommon) << "Getting update logs for type:" << updateType;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(updateType);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("GetUpdateLogs"), argumentList);
@@ -350,6 +389,7 @@ QDBusPendingReply<QString> UpdateDBusProxy::GetUpdateLogs(int updateType)
 
 QDBusPendingReply<void> UpdateDBusProxy::SetIdleDownloadConfig(const QString& config)
 {
+    qCDebug(logCommon) << "Setting idle download config:" << config;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(config);
     return m_updateInter->asyncCallWithArgumentList(QStringLiteral("SetIdleDownloadConfig"), argumentList);
@@ -357,6 +397,7 @@ QDBusPendingReply<void> UpdateDBusProxy::SetIdleDownloadConfig(const QString& co
 
 QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::PrepareDistUpgradePartly(int updateMode)
 {
+    qCDebug(logCommon) << "Preparing partial distribution upgrade with mode:" << updateMode;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(updateMode);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("PrepareDistUpgradePartly"), argumentList);
@@ -364,6 +405,7 @@ QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::PrepareDistUpgradePartly(int
 
 QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::fixError(const QString &errorType)
 {
+    qCDebug(logCommon) << "Fixing error of type:" << errorType;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(errorType);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("FixError"), argumentList);
@@ -371,6 +413,7 @@ QDBusPendingReply<QDBusObjectPath> UpdateDBusProxy::fixError(const QString &erro
 
 QDBusPendingCall UpdateDBusProxy::CheckUpgrade(int checkMode, int checkOrder)
 {
+    qCDebug(logCommon) << "Checking upgrade with mode:" << checkMode << "order:" << checkOrder;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(checkMode) << QVariant::fromValue(checkOrder);
     return m_managerInter->asyncCallWithArgumentList(QStringLiteral("CheckUpgrade"), argumentList);
@@ -378,6 +421,7 @@ QDBusPendingCall UpdateDBusProxy::CheckUpgrade(int checkMode, int checkOrder)
 
 QDBusPendingReply<void> UpdateDBusProxy::GetUpdateDetails(int fd, bool realtime)
 {
+    qCDebug(logCommon) << "Getting update details, fd:" << fd << "realtime:" << realtime;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(QDBusUnixFileDescriptor(fd));
     argumentList << QVariant::fromValue(realtime);
@@ -391,6 +435,7 @@ bool UpdateDBusProxy::onBattery()
 
 BatteryPercentageInfo UpdateDBusProxy::batteryPercentage()
 {
+    qCDebug(logCommon) << "Getting battery percentage info";
     QDBusInterface powerInter(m_powerInter->service(),
                               m_powerInter->path(),
                               PropertiesInterface,
@@ -402,11 +447,13 @@ BatteryPercentageInfo UpdateDBusProxy::batteryPercentage()
     const QDBusArgument arg = v.value<QDBusVariant>().variant().value<QDBusArgument>();
     BatteryPercentageInfo packagesInfo;
     arg >> packagesInfo;
+    qCDebug(logCommon) << "Battery percentage info retrieved";
     return packagesInfo;
 }
 
 void UpdateDBusProxy::commit(const QString &commitDate)
 {
+    qCDebug(logCommon) << "Committing atomic upgrade with date:" << commitDate;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(commitDate);
     m_atomicUpgradeInter->asyncCallWithArgumentList(QStringLiteral("Commit"), argumentList);
@@ -424,6 +471,7 @@ bool UpdateDBusProxy::enable() const
 
 void UpdateDBusProxy::SetEnable(bool enable)
 {
+    qCDebug(logCommon) << "Setting smart mirror enable:" << enable;
     QList<QVariant> argumentList;
     argumentList << QVariant::fromValue(enable);
     m_smartMirrorInter->asyncCallWithArgumentList(QStringLiteral("SetEnable"), argumentList);
@@ -436,13 +484,16 @@ QString UpdateDBusProxy::CurrentUser()
 
 void UpdateDBusProxy::Restart()
 {
+    qCInfo(logCommon) << "Calling system restart";
     m_shutdownFrontInter->asyncCall(QStringLiteral("Restart"));
 }
 void UpdateDBusProxy::UpdateAndReboot()
 {
+    qCInfo(logCommon) << "Calling update and reboot";
     m_shutdownFrontInter->asyncCall(QStringLiteral("UpdateAndReboot"));
 }
 void UpdateDBusProxy::UpdateAndShutdown()
 {
+    qCInfo(logCommon) << "Calling update and shutdown";
     m_shutdownFrontInter->asyncCall(QStringLiteral("UpdateAndShutdown"));
 }
\ No newline at end of file
