@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>Expandeix</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Els usuaris del fòrum de nivell 2 o superior poden unir-se a la prova beta per rebre les últimes actualitzacions.</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>Replega</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>Només es permeten números entre 1 i 99999.</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation>Uniu-vos al canal de proves intern per obtenir les darreres actualitzacions del Deepin.</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
