@@ -25,7 +25,7 @@
     <name>UpdateControl</name>
     <message>
         <source>View Update Log</source>
-        <translation type="unfinished"/>
+        <translation>Aktualisierungs-Protokoll ansehen</translation>
     </message>
 </context>
 <context>
@@ -75,22 +75,22 @@
     </message>
     <message>
         <source>Version:</source>
-        <translation type="unfinished"/>
+        <translation>Version:</translation>
     </message>
 </context>
 <context>
     <name>UpdateLogDialog</name>
     <message>
         <source>Update Log</source>
-        <translation type="unfinished"/>
+        <translation>Aktualisierungs-Protokoll</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished"/>
+        <translation>Schließen</translation>
     </message>
     <message>
         <source>Export to desktop</source>
-        <translation type="unfinished"/>
+        <translation>zum Schreibtisch exportieren</translation>
     </message>
 </context>
 <context>
@@ -247,26 +247,26 @@
     </message>
     <message>
         <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
-        <translation type="unfinished"/>
+        <translation>Das System hat automatische Wiederherstellung eingestellt und unterstützt keine Aktualisierungen. Bei Fragen wenden Sie sich an den Firmen-Administrator</translation>
     </message>
 </context>
 <context>
     <name>UpdateSelectDialog</name>
     <message>
         <source>The updates have been already downloaded. What do you want to do?</source>
-        <translation type="unfinished"/>
+        <translation>Aktualisierungen wurden bereits heruntergeladen. Was möchten Sie tun?</translation>
     </message>
     <message>
         <source>Silent Installation</source>
-        <translation type="unfinished"/>
+        <translation>Installation im Hintergrund</translation>
     </message>
     <message>
         <source>Update and Reboot</source>
-        <translation type="unfinished"/>
+        <translation>Aktualisieren und neustarten</translation>
     </message>
     <message>
         <source>Update and Shut Down</source>
-        <translation type="unfinished"/>
+        <translation>Aktualisieren und herunterfahren</translation>
     </message>
 </context>
 <context>
@@ -365,15 +365,15 @@
     </message>
     <message>
         <source>Collapse</source>
-        <translation type="unfinished"/>
+        <translation>Einfahren</translation>
     </message>
     <message>
         <source>Only numbers between 1-99999 are allowed</source>
-        <translation type="unfinished"/>
+        <translation>Nur Zahlen zwischen 1-99999 sind erlaubt</translation>
     </message>
     <message>
         <source>Join the internal testing channel to get deepin latest updates.</source>
-        <translation type="unfinished"/>
+        <translation>Dem Intern-Test-Kanal beitreten um Deepin-latest-Aktualisierungen zu erhalten.</translation>
     </message>
 </context>
 <context>
@@ -400,11 +400,11 @@
     </message>
     <message>
         <source>Log export failed, please try again</source>
-        <translation type="unfinished"/>
+        <translation>Protokoll exportieren fehgeschlagen, bitte erneut versuchen</translation>
     </message>
     <message>
         <source>The log has been exported to the desktop</source>
-        <translation type="unfinished"/>
+        <translation>Aktualisierungs-Protokoll wurde zum Schreibtisch exportiert</translation>
     </message>
     <message>
         <source>Update</source>
