@@ -365,10 +365,6 @@
         <source>Expand</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation type="unfinished"></translation>
@@ -377,6 +373,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
