@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>Uitklappen</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Forumgebruikers met niveau 2 of hoger kunnen deelnemen aan de bètatest.</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>Inklappen</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>Alleen getallen tussen de 1 en 99999 zijn toegestaan</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation>Schakel het interne testkanaal in om de nieuwste Deepin-updates te ontvangen.</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
